@@ -13,11 +13,8 @@ if ! [ -e /usr/bin/gtkdocize ]; then
 fi
 
 [[ $(command -v gtk4-launch) == "" ]] && OPTION="--disable-gtk4" || OPTION=""
-[[ $(command -v wayland-scanner) != "" ]] && OPTION="$OPTION --enable-wayland"
-[[ $(command -v gtkdocize) != "" ]] && OPTION="$OPTION --enable-gtk-doc"
-[[ $(command -v systemctl) == "" ]] && OPTION="$OPTION --disable-systemd-services"
 
-SAVE_DIST_FILES=1 NOCONFIGURE=1 ./autogen.sh
+SAVE_DIST_FILES=1 NOCONFIGURE=1 ./autogen.sh &&
 
 PYTHON=python3                     \
 ./configure --prefix=/usr          \
@@ -27,7 +24,8 @@ PYTHON=python3                     \
             --disable-emoji-dict   \
             --disable-gtk2         \
 			--enable-python-library	\
-             $OPTION
+			--enable-wayland		\
+            --disable-systemd-services $OPTION
 make
 
 # As root:
